@@ -1,5 +1,5 @@
 use {
-    crate::{state::*},
+    crate::{state::*, errors::*},
     anchor_lang::{prelude::*},
     cardinal_token_manager::{program::CardinalTokenManager, state::{TokenManager}}, 
 };
@@ -9,7 +9,10 @@ pub struct InvalidateCtx<'info> {
     #[account(mut)]
     token_manager: Box<Account<'info, TokenManager>>,
 
-    #[account(mut, close = invalidator)]
+    #[account(mut,
+        constraint = Clock::get().unwrap().unix_timestamp >= time_invalidator.expiration @ ErrorCode::InvalidIssuerTokenAccount,
+        close = invalidator
+    )]
     time_invalidator: Box<Account<'info, TimeInvalidator>>,
 
     #[account(mut)]
@@ -30,7 +33,7 @@ pub fn handler(ctx: Context<InvalidateCtx>) -> ProgramResult {
     let time_invalidator_seeds = &[TIME_INVALIDATOR_SEED.as_bytes(), token_manager_key.as_ref(), &[ctx.accounts.time_invalidator.bump]];
     let time_invalidator_signer = &[&time_invalidator_seeds[..]];
 
-    // claim certificate
+    // invalidate
     let cpi_accounts = cardinal_token_manager::cpi::accounts::InvalidateCtx {
         token_manager: ctx.accounts.token_manager.to_account_info(),
         token_manager_token_account: ctx.accounts.token_manager_token_account.to_account_info(),
